LVGP_predict: The Prediction Function of 'LVGP' Package

View source: R/LVGP_predict.R

LVGP_predictR Documentation

The Prediction Function of LVGP Package

Description

Predicts the output and associated uncertainties of the GP model fitted by LVGP_fit.

Usage

LVGP_predict(X_new, model, MSE_on = 0)

Arguments

X_new

Matrix or vector containing the input(s) where the predictions are to be made. Each row is an input vector.

model

The LVGP model fitted by LVGP_fit.

MSE_on

A scalar indicating whether the uncertainty (i.e., mean squared error MSE) is calculated. Set to a non-zero value to calculate MSE.

Value

A prediction list containing the following components:

Y_hat

A vector containing the mean prediction values

MSE

A vector containing the prediction uncertainty (i.e., the covariance or covariance matrix for the output(s) at prediction location(s))

References

  1. "A Latent Variable Approach to Gaussian Process Modeling with Qualitative and Quantitative Factors", Yichi Zhang, Siyu Tao, Wei Chen, and Daniel W. Apley (arXiv)

See Also

LVGP_fit to fit LVGP model to the datasets.
LVGP_plot to plot the features of the fitted model.

Examples

# see the examples in the documentation of the function LVGP_fit.

LVGP documentation built on July 21, 2026, 5:06 p.m.

Related to LVGP_predict in LVGP...