corr_mat: The Function for Constructing the Correlation Matrix in LVGP Package
Description
Builds the correlation matrix given two datasets, and the type and parameters of the correlation function.
Usage
corr_mat(X1, X2, phi_full)
Arguments
X1, X2
Matrices containing the data points. The rows and columns of both X1 and X2 denote individual observation settings and dimension, respectively.
phi_full
The vector storing all the scale (aka roughness) parameters of the correlation function. See reference 1.
Value
R The Correlation matrix with size nrow(X1)-by-nrow(X2). See here.
References
"A Latent Variable Approach to Gaussian Process Modeling with Qualitative and Quantitative Factors", Yichi Zhang, Siyu Tao, Wei Chen, and Daniel W. Apley (arXiv)
See Also
LVGP_fit to see how a GP model can be fitted to a training dataset.
LVGP_predict to use the fitted LVGP model for prediction.
LVGP_plot to plot the features of the fitted model.