neg_log_l: The Negative Log-Likelehood Function in LVGP Package
Description
Calculates the negative log-likelihood (excluding all the constant terms) as described in reference 1.
Usage
neg_log_l(hyperparam, p_quant, p_qual, lvs_qual, n_lvs_qual, dim_z,
X_quant, X_qual, Y, min_eig, k, M)
Arguments
hyperparam
Hyperparameters of the LVGP model
p_quant
Number of quantative variables
p_qual
Number of qualitative variables
lvs_qual
Levels of each qualitative variable
n_lvs_qual
Number of levels of each qualitative variable
dim_z
Dimensionality of latent variables, usually 1 or 2
X_quant
Input data of quantative variables
X_qual
Input data of qualitative variables
Y
Vector containing the outputs of data points
min_eig
The smallest eigen value that the correlation matrix is allowed to have, which determines the nugget added to the correlation matrix.
k
Number of data points, nrow(X_quant) or nrow(X_qual)
M
Vector of ones with length k
Value
The negative log-likelihood (excluding all the constant terms) value.
Details
LVGP_fit calls this function as its optimization objective function.
References
"A Latent Variable Approach to Gaussian Process Modeling with Qualitative and Quantitative Factors", Yichi Zhang, Siyu Tao, Wei Chen, and Daniel W. Apley (arXiv)
See Also
LVGP_fit to see how a GP model can be fitted to a training dataset.
LVGP_predict to use the fitted LVGP model for prediction.
LVGP_plot to plot the features of the fitted model.