to_latent: The Function for Transforming Qualitative/Categorical Variables into Latent Variables in LVGP Package
Description
Transforms qualitative/categorical variables into latent variables.
Usage
to_latent(X_qual, lvs_qual, n_lvs_qual, p_qual, z_vec, dim_z, k)
Arguments
X_qual
Matrix or data frame containing (only) the qualitative/categorical data.
lvs_qual
List containing levels of each qualitative variable
n_lvs_qual
Number of levels of each qualitative variable
p_qual
Number of qualitative variables
z_vec
Latent variable parameters, i.e., latent variable values for each level of qualitative/categorical variables
dim_z
Dimensionality of latent variables, usually 1 or 2
k
Number of data points, equal to nrow(X_qual)
Value
Matrix containing transformed data
References
"A Latent Variable Approach to Gaussian Process Modeling with Qualitative and Quantitative Factors", Yichi Zhang, Siyu Tao, Wei Chen, and Daniel W. Apley (arXiv)
See Also
LVGP_fit to see how a GP model can be fitted to a training dataset.
LVGP_predict to use the fitted LVGP model for prediction.
LVGP_plot to plot the features of the fitted model.
Examples
Run this code# NOT RUN {
# see the examples in the documentation of the function LVGP_fit.
# }
Run the code above in your browser using DataLab